@@ -3,8 +3,9 @@ import json
 import os
 
 
-def cognito_list_identity_pool(region):
-    client = boto3.client('cognito-identity', region_name=region)
+def cognito_list_identity_pool(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('cognito-identity', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     response = client.list_identity_pools(
         MaxResults=10,
     )
